
TODO_49_31_47_63:
Add `query` (instead of `describe` or `itemize`) internal command to do exactly the same what Ctrl+Alt+Q does, but via Invocation.
Rename "describe" / "itemize" / "enum" / "search" / "outline" to `enum_query` (or "query") and implement function which does what Alt+Shift+Q does but on enter.

Rename to `query_enum_items` (with `SpecialFunc.query_enum_items_func` as `func_id`).

See also: FS_80_45_89_81 / query_enum_items
